// LST-S2 camera mount for BetaFPV canopy 
// Material: ABS

// Parameters

// Render quality / Качество отрисовки
$fn=128; // [32:32:128]
// Diameter of mounting holes / Диаметр крепежных отверстий
mountholes = 1.6; // [0.8:0.05:3]
// Thickness of base mount / Толщина основания
mountheight = 1; // [0.2:0.05:2]
// Used Beecore V2 D16 / Используется Beecore V2 D16
mountbeecore = true; // [true,false]
// Mount angle / Угол наклона крепления камеры 22
camangle = 25; // [15:0.5:35]
// Height of camera mount / Высота установки камеры 14.2
camzpos = 13.8; // [12.5:0.1:15]
// Horizontal position / Горизонтальное положение 4.75
camxpos = 4.75; // [3:0.05:6]
// Camera inside width / Ширина внутренней части
caminswidth = 10.6; // [0:0.05:28]
// Rotate vertical wall / Поворот вертикальной стенки
caminangle = -3; // [-3:0.5:3]
// Camera shift / Смещение камеры
camshift = 0; // [-1:0.05:1]
// Show LST-S2 camera / Показывать камеру LST-S2
showcamera = false; // [true,false]

//-------------------------------------------------------------------
// Do not edit following lines
//-------------------------------------------------------------------

include <camera.scad>

module camera_mount() {
    // bottom
    mount();
    difference() {
        // top
        translate([-camxpos,0,camzpos]) rotate([0,-abs(camangle-3),0]) cammount();
        // cut bottom
        translate([-20,0,-25+mountheight]) cube([50,20,50], center=true);
   }
}

module mount() {
    // From center to mount holes. Different frame - different value: 18.0 or 18.385
    mount_size=18.385;
    difference() {
        union(){
            // left mount
            //translate([-mount_size,-mount_size,0]) cylinder(r=2.1,h=mountheight);
            // right mount
            //translate([-mount_size,mount_size,0]) cylinder(r=2.1,h=mountheight);
            // front mount
            translate([0,0,0]) cylinder(r=2.1,h=mountheight);
            // rear mount
            translate([-2*mount_size,0,0]) cylinder(r=2.1,h=mountheight);
            // front mount
            translate([-mount_size,0,mountheight/2]) cube([36,4,mountheight], center=true);
            // side mount
            //translate([-mount_size,0,mountheight/2]) cube([4,36,mountheight], center=true);
            if (mountbeecore) translate([-2*mount_size+8.5,0,0]) cylinder(r=5.25,h=mountheight);
        }
        // mount holes
        //translate([-mount_size,-mount_size,-1]) cylinder(r=mountholes/2,h=mountheight+2);
        //translate([-mount_size,mount_size,-1]) cylinder(r=mountholes/2,h=mountheight+2);
        translate([0,0,-1]) cylinder(r=mountholes/2,h=mountheight+2);
        translate([-2*mount_size,0,-1]) cylinder(r=mountholes/2,h=mountheight+2);
        if (mountbeecore) translate([-2*mount_size+8.5,0,-1]) cylinder(r=3.25,h=mountheight+2);
    }
}

module cammount() {
    // show camera
    if (showcamera) translate([-11,0,-5.825]) rotate([0,-3,0]) camera();
    // vertical wall
    translate([-7.75,camshift,-6]) rotate([0,0,caminangle]) difference() {
        translate([0,0,-4]) cube([1.2,caminswidth,20],center=true);
        translate([0,0,6]) scale([1,1,1.5]) rotate([0,90,0]) cylinder(r=3.2,h=2, center=true);
        translate([0,5.5,-5.1]) rotate([0,90,0]) cylinder(r=4,h=2,center=true);
        translate([0,-5.5,-5.1]) rotate([0,90,0]) cylinder(r=4.,h=2,center=true);
        translate([0,6.5,-12.1]) cube([2,10,14],center=true);
        translate([0,-6.5,-12.1]) cube([2,10,14],center=true);
    }
    // horizontal plate
    translate([-22.5,0,-6.45]) difference() {
        translate([0,camshift,0]) cube([30,caminswidth-0.1,1.2],center=true);
        translate([8, 5.5,0]) cylinder(r=4,h=2,center=true);
        translate([8,-5.5,0]) cylinder(r=4,h=2,center=true);
        translate([-4,6.5,0]) cube([24,10,2],center=true);
        translate([-4,-6.5,0]) cube([24,10,2],center=true);
    }
    // around lens
    translate([-0.2,0,-1.6]) rotate([0,90-3,0]) linear_extrude(height=1.5,center=true) import("lensfix.svg",convexity=10);
    // lens stand
    translate([-0,0,-3.5]) rotate([0,camangle-3,0]) translate([0,0,-7]) cube([1.2,4,14],center=true);
    // vertical reinforcement
    difference() {
        translate([-20,0,-13]) cube([40,1,20],center=true);
        translate([-7.3,0,3.6]) rotate([90,0,0]) cylinder(r=10,h=2,center=true);
        translate([-26.5,0,-1]) cube([40,2,10],center=true);
        translate([0,0,-3.5]) rotate([0,camangle-3,0]) translate([10,0,-10]) cube([20,4,30],center=true);
    }
}

// show camera mount
camera_mount();

